#ifndef _KSYMS_H_
#define _KSYMS_H_

/* Returned by ksymtocode to report an unknown symbol */
#define CODE_FOR_UNKNOWN_KSYM (-1)

#include <stdint.h>

typedef struct {
  int /* boolean */ with_case;
  enum { UNICODE, EIGHT_BIT } uni_or_8;
  uint16_t val;
} ksym_expr;
/* Special consts: */
#define UNICODE_ERROR 0xffff /* Noncharacter, privately used here. */
static const ksym_expr KSYM_EXPR_ERR = { 0, UNICODE, UNICODE_ERROR };
/* Constructors: */
extern ksym_expr ksym_expr_8bit(short val);
extern ksym_expr ksym_expr_unicode(short val);
extern ksym_expr ksymtocode(char *s);
/* Check whether we have read successfully: */
extern int is_ksymtocode_ok(ksym_expr k);
/* Modifiers: */
extern ksym_expr ksym_expr_with_case(ksym_expr k);
extern ksym_expr ksym_expr_explicit(ksym_expr k);
/* Methods: */
extern int /* boolean */ ksym_expr_print_numeric;
/* The basic representation for the keysym (as in a keymap file).
 * Alloc's strings, so they must be freed afterwards in a perfect program;
 * probably, your program won't be perfect, so you allow for unfreed return values
 */
extern const char * ksym_expr_print(ksym_expr k);

typedef struct {
	char **table;
	int size;
} syms_entry;

struct cs {
    char *charset;
    char **charnames;
    int start;
};

extern struct cs charsets[];

extern syms_entry syms[];

struct syn {
	char *synonym;
	char *official_name;
};
extern struct syn synonyms[];

extern const int syms_size;
extern const int syn_size;
extern const int charsets_size;

extern int set_charset(char *name);

#endif
